IntRange class
정수 자료형 int 의 범위에 대한 다양한 기능을 제공합니다.
Properties
- difference → int
-
최솟값과 최댓값의 차이를 반환합니다.
no setterinherited
- end → int
-
최댓값을 반환합니다.
no setterinherited
-
excludes
→ List<
_NumRange< ?int> > -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
해당 범위의 길이를 반환합니다.
no setterinherited
- range → (int, int)
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
최솟값을 반환합니다.
no setterinherited
-
subRanges
→ List<
_NumRange< int> > -
excludes를 제외한 부분범위 리스트를 반환합니다.no setterinherited
Methods
-
contains(
int num) → bool -
num이 범위에 포함되는지 여부를 반환합니다.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited